%global srcname conda-package-streaming
%global pkgname conda_package_streaming

%bcond_with bootstrap

Summary:        Extract metadata from remote conda packages without downloading whole file
Name:           python-%{srcname}
Version:        0.9.0
Release:        2%{?dist}
License:        BSD-3-Clause
URL:            https://github.com/conda/conda-package-streaming
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz

BuildArch:      noarch

%description
An efficient library to read from new and old format .conda and .tar.bz2 conda packages.

Download conda metadata from packages without transferring entire file. Get
metadata from local .tar.bz2 packages without reading entire files.

Uses enhanced pip lazy_wheel to fetch a file out of .conda with no more than 3
range requests, but usually 2.

Uses tar = tarfile.open(fileobj=...) to stream remote .tar.bz2. Closes the HTTP
request once desired files have been seen.

%package -n python%{python3_pkgversion}-%{srcname}
Summary:        Extract metadata from remote conda packages without downloading whole file
BuildRequires:  python%{python3_pkgversion}-devel

%if %{without bootstrap}
BuildRequires:  conda
%endif

%description -n python%{python3_pkgversion}-%{srcname}
An efficient library to read from new and old format .conda and .tar.bz2 conda packages.

Download conda metadata from packages without transferring entire file. Get
metadata from local .tar.bz2 packages without reading entire files.

Uses enhanced pip lazy_wheel to fetch a file out of .conda with no more than 3
range requests, but usually 2.

Uses tar = tarfile.open(fileobj=...) to stream remote .tar.bz2. Closes the HTTP
request once desired files have been seen.

%prep
%autosetup -n %{srcname}-%{version} -p1

sed -i -e '/cov/d' -e '/boto3-stubs/d' pyproject.toml requirements.txt
%if %{with bootstrap}
sed -i -e '/"conda"/d' -e '/conda-package-handling/d' pyproject.toml
%endif

%generate_buildrequires
%pyproject_buildrequires -x test

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pkgname}

%check
%if %{without bootstrap}
. /etc/profile.d/conda.sh
export CONDA_EXE
%pytest -v tests \
  --deselect=tests/test_transmute.py::test_transmute \
  --deselect=tests/test_transmute.py::test_transmute_backwards \
  --deselect=tests/test_url.py::test_lazy_wheel
%else
%pytest -v tests/test_degraded.py
%endif

%files -n python%{python3_pkgversion}-%{srcname} -f %{pyproject_files}
%license %{python3_sitelib}/conda_package_streaming-%{version}.dist-info/LICENSE
%doc README.md

%changelog
* Mon Dec 11 2023 Shuo Wang <abushwang@tencent.com> - 0.9.0-2
- disable bootstrap

* Fri Dec 8 2023 Shuo Wang <abushwang@tencent.com> - 0.9.0-1
- initial build
